@@ -13,8 +13,8 @@ import libsmbios_c
 _modpath = os.path.realpath(libsmbios_c.__path__[0])
 
 # the following vars are all substituted on install
-__VERSION__="2.2.16"
-GETTEXT_PACKAGE="libsmbios-2.2"
+__VERSION__="2.2.19"
+GETTEXT_PACKAGE="libsmbios-2.2-x86_64"
 libdir="/usr/local/lib"
 pythondir="/usr/local/lib/python2.5/site-packages"
 localedir="/usr/local/share/locale"
